package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.common.core.domain.entity.FormalParentsStudent;

/**
 * 家长-学生(审核通过之后数据)Service接口
 * 
 * @author ruoyi
 * @date 2023-05-30
 */
public interface IFormalParentsStudentService 
{
    /**
     * 查询家长-学生(审核通过之后数据)
     * 
     * @param id 家长-学生(审核通过之后数据)主键
     * @return 家长-学生(审核通过之后数据)
     */
    public FormalParentsStudent selectFormalParentsStudentById(Long id);

    /**
     * 查询家长-学生(审核通过之后数据)列表
     * 
     * @param formalParentsStudent 家长-学生(审核通过之后数据)
     * @return 家长-学生(审核通过之后数据)集合
     */
    public List<FormalParentsStudent> selectFormalParentsStudentList(FormalParentsStudent formalParentsStudent);

    /**
     * 新增家长-学生(审核通过之后数据)
     * 
     * @param formalParentsStudent 家长-学生(审核通过之后数据)
     * @return 结果
     */
    public int insertFormalParentsStudent(FormalParentsStudent formalParentsStudent);

    /**
     * 修改家长-学生(审核通过之后数据)
     * 
     * @param formalParentsStudent 家长-学生(审核通过之后数据)
     * @return 结果
     */
    public int updateFormalParentsStudent(FormalParentsStudent formalParentsStudent);

    /**
     * 批量删除家长-学生(审核通过之后数据)
     * 
     * @param ids 需要删除的家长-学生(审核通过之后数据)主键集合
     * @return 结果
     */
    public int deleteFormalParentsStudentByIds(Long[] ids);

    /**
     * 删除家长-学生(审核通过之后数据)信息
     * 
     * @param id 家长-学生(审核通过之后数据)主键
     * @return 结果
     */
    public int deleteFormalParentsStudentById(Long id);
}
